<template>
  <div class="p-3 p-md-4" role="tabpanel" :dir="isRTL ? 'rtl' : 'ltr'">
    <div class="row justify-content-center">
      <div class="col-lg-12">
        <div class="card border-0 shadow-sm rounded-4">
          <div class="card-body p-4">
            <div class="d-flex align-items-center justify-content-between mb-4">
              <h5 class="mb-0 fw-bold text-default">
                {{ t('account.language.title') }}
              </h5>
              <span class="badge text-default" style="background-color: rgba(255, 152, 0, 0.1);">
                <i class="icon fw-light icon-regular-globe ms-1 text-default"></i>
                {{ t('account.language.choose_language') }}
              </span>
            </div>

            <div class="list-group">
              <button
                  v-for="lang in languages"
                  :key="lang.code"
                  type="button"
                  class="list-group-item list-group-item-action d-flex justify-content-between rounded-1 align-items-center"
                  :class="{ active: lang.code === selected }"
                  @click="changeLanguage(lang.code)"
              >
                <span class="d-flex align-items-center gap-2">
                  <img :src="lang.flag" alt="flag" style="width: 24px; height: 16px;" />
                  {{ lang.title }}
                </span>
                <span v-if="lang.code === selected" >
                  <i class="icon icon-regular-check-square font-size-25 align-middle mt-1 d-block text-white"></i>
                </span>
              </button>
            </div>

            <div class="mt-4">
              <button class="btn btn-secondary w-100" @click="submitLocale">
                {{ t('account.language.submit') }}
              </button>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n'
import { useCookie } from '#app'
import {ref, computed, nextTick} from 'vue'
import {useRouter} from "vue-router";

// Variable
const { t, locale,i18n } = useI18n();
const router = useRouter();

// Data
const languages = ref([
  { code: 'fa', title: 'فارسی', flag: '/flags/iran.svg' },
  { code: 'en', title: 'English', flag: '/flags/england.svg' },
  { code: 'ar', title: 'العربية', flag: '/flags/saudi-arabia.svg' }
])

const isRTL = computed(() => ['fa', 'ar'].includes(locale.value));

const selected = ref(locale.value);

// Actions
const changeLanguage = (code) => {
 selected.value = code;
}

const submitLocale = async () => {
  locale.value = selected.value // تغییر زبان

  // ذخیره در کوکی (در صورت نیاز)
  useCookie('locale').value = selected.value
  useCookie('locale_selected').value = true

  // اعمال تغییرات
  await nextTick() // صبر کن تا Vue بروزرسانی کنه

  // اگر هنوز مشکل داشت:
  router.go(0) // فقط در صورت نیاز، رفرش نرم
}

</script>

<style scoped>
.list-group-item.active {
  background-color: #ff9800;
  border-color: #ff9800;
  color: white;
}
</style>
